mangadap.proc.emissionlinemodel module
======================================

.. automodule:: mangadap.proc.emissionlinemodel
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
